﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.Xml.Linq;
using Infragistics.Controls.Schedules;
using System.Reflection;

namespace XamScheduleTheming
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            Loaded += new RoutedEventHandler(MainWindow_Loaded);
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            var resources = new ObservableCollection<Resource>();
            resources.Add(new Resource
            {
                Id = "own1",
                Name = "Amanda"
            });

            var calendars = new ObservableCollection<ResourceCalendar>();
            calendars.Add(new ResourceCalendar
            {
                Id = "cal1",
                OwningResourceId = "own1"
            });

            var appointments = new ObservableCollection<Appointment>();
            appointments.Add(new Appointment
            {
                Id = "t1",
                OwningCalendarId = "cal1",
                OwningResourceId = "own1",
                Subject = "Code review",
                Description = "Reviewing George's code",
                // Convert the date to universal time, because a time zone is not set
                // in this snippet    
                Start = DateTime.Now.AddMinutes(3).ToUniversalTime(),
                End = DateTime.Now.AddHours(1).ToUniversalTime(),
                //set a reminder timer 1 minute before the appointment
                ReminderEnabled = true,
                ReminderInterval = TimeSpan.FromMinutes(1)
            });
            appointments.Add(new Appointment
            {
                Id = "t2",
                OwningCalendarId = "cal1",
                OwningResourceId = "own1",
                Subject = "Conference call with customers",
                Description = "Requirements elicitation meeting",
                // Convert the date to universal time, because a time zone is not set
                // in this snippet    
                Start = DateTime.Now.AddHours(2).AddMinutes(12).ToUniversalTime(),
                End = DateTime.Now.AddHours(3).AddMinutes(15).ToUniversalTime(),
                ReminderEnabled = true,
                ReminderInterval = TimeSpan.FromMinutes(30)
            });

            //set the appointments to the data connection, to make them available to the XamSchedule data manager
            dataConnector.ResourceItemsSource = resources;
            dataConnector.ResourceCalendarItemsSource = calendars;
            dataConnector.AppointmentItemsSource = appointments;
        }

        private void dataManager_Loaded(object sender, RoutedEventArgs e)
        {
            dataManager.ColorScheme = new Office2010ColorScheme();
        }

        private void colorSchemeCombo_Loaded(object sender, RoutedEventArgs e)
        {
            //load color schemes into the color schemes combobox
            OfficeColorScheme[] colorSchemes = HelpMethods.EnumGetValues<OfficeColorScheme>();

            foreach (OfficeColorScheme colorScheme in colorSchemes)
            {
                Office2007ColorScheme office2007 = new Office2007ColorScheme() { OfficeColorScheme = colorScheme };
                Office2010ColorScheme office2010 = new Office2010ColorScheme() { OfficeColorScheme = colorScheme };
                colorSchemeCombo.Items.Add(new ComboBoxItem() { Content = "Office2007" + colorScheme.ToString(), Tag = office2007 });
                colorSchemeCombo.Items.Add(new ComboBoxItem() { Content = "Office2010" + colorScheme.ToString(), Tag = office2010 });
            }

            colorSchemeCombo.SelectedIndex = 0;
        }

        private void colorSchemeCombo_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (colorSchemeCombo.SelectedIndex != -1)
            {
                dataManager.ColorScheme = (CalendarColorScheme)(((ComboBoxItem)(colorSchemeCombo.SelectedItem)).Tag);
            }
        }
    }

    public static class HelpMethods
    {
        /// <summary>
        /// Returns an array of enum values for a type
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <returns></returns>
        public static T[] EnumGetValues<T>()
        {
            Type enumType = typeof(T);

            if (!enumType.IsEnum)
            {
                throw new ArgumentException("Type '" + enumType.Name + "' is not an enum");
            }

            List<T> values = new List<T>();

            FieldInfo[] fields = enumType.GetFields();

            foreach (FieldInfo field in fields)
            {
                if (field.IsLiteral)
                {
                    object value = field.GetValue(enumType);
                    values.Add((T)value);
                }
            }

            return values.ToArray();
        }
    }
}